@@ -86,8 +86,8 @@ class KdpConn(object):
 
             :rtype: set
         """
-        write_api = WriteApi()
         config = self.create_configuration(jwt)
+        write_api = WriteApi(configuration=config)
         return write_api.batch_write(config=config, dataset_id=dataset_id, dataframe=dataframe, batch_size=batch_size, is_async=is_async)
 
 
@@ -115,7 +115,7 @@ class KdpConn(object):
             :rtype: set
         """
         config = self.create_configuration(jwt)
-        write_api = WriteApi(config)
+        write_api = WriteApi(configuration=config)
         return write_api.batch_write_v2(
             config=config,
             dataset_id=dataset_id,
