@@ -20,7 +20,7 @@ class TestIngest(unittest.TestCase):
                                                        dataset_id=self.dataset_id,
                                                        partitions=[0, 1])
         self.api_instance = Mock()
-        self.api_instance.write.return_value = self.write_batch_response
+        self.api_instance.post_write_id.return_value = self.write_batch_response
 
     @staticmethod
     def getDataframe(size: int):
@@ -56,7 +56,7 @@ class TestIngest(unittest.TestCase):
                         kdp_conn = KdpConn()
                         partitions_set = kdp_conn.batch_write(self.getDataframe(case.records), self.dataset_id, self.JWT,
                                                               case.batch_size)
-                        self.assertEqual(len(mock_api_instance.write.mock_calls), case.expected_batches,
+                        self.assertEqual(len(mock_api_instance.post_write_id.mock_calls), case.expected_batches,
                                          'FAILURE: for records=' + str(case.records) +
                                          ' and batch_size=' + str(case.batch_size) +
                                          ' expected_batches did not equal ' + str(case.expected_batches))
@@ -78,7 +78,7 @@ class TestIngest(unittest.TestCase):
                     kdp_conn = KdpConn()
                     partitions_set = kdp_conn.batch_write(self.getDataframe(4), self.dataset_id, self.JWT,
                                                           self.batch_size)
-                    mock_api_instance.write.assert_has_calls(expected_write_calls)
+                    mock_api_instance.post_write_id.assert_has_calls(expected_write_calls)
 
         expected_partitions_set = {0, 1}
         self.assertEqual(expected_partitions_set, partitions_set)
